Control Models
==============

.. automodule:: stonesoup.models.control
    :no-members:

.. automodule:: stonesoup.models.control.base
    :show-inheritance:

.. automodule:: stonesoup.models.control.linear
	:show-inheritance: